<?php

namespace Payroll\Employee\Http\Controllers;
use Litepie\Employee\Http\Requests\EmployeeRequest;
use Litepie\Employee\Models\Employee;

trait EmployeeWorkflow {
	
    /**
     * Workflow controller function for employee.
     *
     * @param Model   $employee
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(EmployeeRequest $request, Employee $employee, $step)
    {

        try {

            $employee->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('employee::employee.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/employee/employee/' . $employee->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/employee/employee/' . $employee->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for employee.
     *
     * @param Model   $employee
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
    */

    public function getWorkflow(Employee $employee, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $employee->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('employee::employee.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('employee::admin.employee.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('employee::admin.employee.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage(). '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('employee::admin.employee.message', $data)->render();

        }

    }
}