<?php

namespace Payroll\Employee\Policies;

use App\User;
use Payroll\Employee\Models\Employee;

class EmployeePolicy
{

    /**
     * Determine if the given user can view the employee.
     *
     * @param User $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function view(User $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.view') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.view') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $employee->user_id;
    }

    /**
     * Determine if the given user can create a employee.
     *
     * @param User $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('employee.employee.create');
    }

    /**
     * Determine if the given user can update the given employee.
     *
     * @param User $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function update(User $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.update') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.update') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $employee->user_id;
    }

    /**
     * Determine if the given user can delete the given employee.
     *
     * @param User $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function destroy(User $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.delete') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('blocks.block.delete') 
        && $user->is('manager')
        && $block->user->parent_id == $user->id) {
            return true;
        }

        return $user->id === $employee->user_id;
    }

    /**
     * Determine if the given user can verify the given employee.
     *
     * @param User $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function verify(User $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.verify') && $user->is('admin')) {
            return true;
        }

        if ($user->canDo('employee.employee.verify') 
        && $user->is('manager')
        && $employee->user->parent_id == $user->id) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employee.
     *
     * @param User $user
     * @param Employee $employee
     *
     * @return bool
     */
    public function approve(User $user, Employee $employee)
    {
        if ($user->canDo('employee.employee.approve') && $user->is('admin')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
