<?php

namespace Payroll\Employee\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Payroll\Employee\Models\Employee;

class EmployeeAction
{
    /**
     * Perform the complete action.
     *
     * @param Employee $employee
     *
     * @return Employee
     */
    public function complete(Employee $employee)
    {
        try {
            $employee->status = 'complete';
            return $employee->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Employee $employee
     *
     * @return Employee
     */public function verify(Employee $employee)
    {
        try {
            $employee->status = 'verify';
            return $employee->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Employee $employee
     *
     * @return Employee
     */public function approve(Employee $employee)
    {
        try {
            $employee->status = 'approve';
            return $employee->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Employee $employee
     *
     * @return Employee
     */public function publish(Employee $employee)
    {
        try {
            $employee->status = 'publish';
            return $employee->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Employee $employee
     *
     * @return Employee
     */
    public function archive(Employee $employee)
    {
        try {
            $employee->status = 'archive';
            return $employee->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Employee $employee
     *
     * @return Employee
     */
    public function unpublish(Employee $employee)
    {
        try {
            $employee->status = 'unpublish';
            return $employee->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
