<?php

namespace Payroll\Employee\Workflow;

use Payroll\Employee\Models\Employee;
use Validator;

class EmployeeValidator
{

    /**
     * Determine if the given employee is valid for complete status.
     *
     * @param Employee $employee
     *
     * @return bool / Validator
     */
    public function complete(Employee $employee)
    {
        return Validator::make($employee->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given employee is valid for verify status.
     *
     * @param Employee $employee
     *
     * @return bool / Validator
     */
    public function verify(Employee $employee)
    {
        return Validator::make($employee->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given employee is valid for approve status.
     *
     * @param Employee $employee
     *
     * @return bool / Validator
     */
    public function approve(Employee $employee)
    {
        return Validator::make($employee->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given employee is valid for publish status.
     *
     * @param Employee $employee
     *
     * @return bool / Validator
     */
    public function publish(Employee $employee)
    {
        return Validator::make($employee->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given employee is valid for archive status.
     *
     * @param Employee $employee
     *
     * @return bool / Validator
     */
    public function archive(Employee $employee)
    {
        return Validator::make($employee->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given employee is valid for unpublish status.
     *
     * @param Employee $employee
     *
     * @return bool / Validator
     */
    public function unpublish(Employee $employee)
    {
        return Validator::make($employee->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
